==> KEGG_1.14.1.tar.gz: KEGG/man/KEGGEXTID2PATHID.Rd <==
\name{KEGGEXTID2PATHID}
\alias{KEGGEXTID2PATHID}
\title{An annotation data file that maps Entrez Gene or Open Reading Frame
  identifiers KEGG pathway identifiers}
\description{
  KEGGEXTID2PATHID maps Entrez Gene (for human, mouse, and rat)
  and Open Reading Frame (for yeast) identifiers to KEGG pathway identifiers.   
}
\details{
  This is an environment object containing key and value pairs. Keys are
  Entrez Gene identifiers for human, mouse, and rat and Open Reading Frame (ORF) identifiers for
  yeast and values are the corresponding KEGG pathway identifiers. Values are
  vectors of length 1 or greater depending on whether a given external
  identifier can be mapped to only one or more KEGG pathway identifiers.  NAs are
  assigned to Entrez Gene or ORF identifiers that can not be mapped to any pathway
  identifier.

  KEGG pathway identifiers are the identifiers used by KEGG for various
  pathways.

  Mappings between KEGG pathway identifiers and pathway names can be obtained
  through another environment named PATHID2NAME. 

  Mappings were based on data provided by:

  KEGG:\url{http://gopher5/compbio/annotationSourceData/kegg/pathways/map_title.tab}. Built: Release 38.1, June 1, 2006

  Package built: Wed Sep  6 13:12:02 2006
}
\references{
\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(KEGGEXTID2PATHID)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[[1]]
		# Get the values for multiget for a few keys
		if(length(xx) >= 3){
			xx[1:3]
		}
	}
}
\keyword{datasets}

==> KEGG_1.16.1.tar.gz: KEGG/man/KEGGEXTID2PATHID.Rd <==
\name{KEGGEXTID2PATHID}
\alias{KEGGEXTID2PATHID}
\title{An annotation data file that maps Entrez Gene or Open Reading Frame
  identifiers KEGG pathway identifiers}
\description{
  KEGGEXTID2PATHID maps Entrez Gene (for human, mouse, and rat)
  and Open Reading Frame (for yeast) identifiers to KEGG pathway identifiers.   
}
\details{
  This is an environment object containing key and value pairs. Keys are
  Entrez Gene identifiers for human, mouse, and rat and Open Reading Frame (ORF) identifiers for
  yeast and values are the corresponding KEGG pathway identifiers. Values are
  vectors of length 1 or greater depending on whether a given external
  identifier can be mapped to only one or more KEGG pathway identifiers.  NAs are
  assigned to Entrez Gene or ORF identifiers that can not be mapped to any pathway
  identifier.

  KEGG pathway identifiers are the identifiers used by KEGG for various
  pathways.

  Mappings between KEGG pathway identifiers and pathway names can be obtained
  through another environment named PATHID2NAME. 

  Mappings were based on data provided by:

  KEGG:\\url{http://gopher6/compbio/annotationSourceData/kegg/pathways/map\_title.tab}. Built: Release 41.1, February 1, 2007

  Package built: Fri Mar 16 09:54:27 2007
}
\references{
\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}
}
\examples{
	require("annotate") || stop("annotate unavailable")
	xx <- as.list(KEGGEXTID2PATHID)
	if(length(xx) > 0){
		# Get the value of the first key
		xx[[1]]
		# Get the values for multiget for a few keys
		if(length(xx) >= 3){
			xx[1:3]
		}
	}
}
\keyword{datasets}
